#!/bin/ash
#demo script for gtkdialog1 using aumix as mixer backend
#may2013/june2013 goingnuts
#TODO:
#find all devices and auto configure

#[[ -x ../../src/gtkdialog1 ]] && PATH=../../src:$PATH

[ ! $(which aumix) ] && echo "I need program aumix to run..." && exit

#create a styleset
echo '
style "tooltips" {
  bg[NORMAL] = "#ffd000"
  fg[NORMAL] = "#000000"
  font = "-adobe-helvetica-medium-r-normal--*-120-*-*-*-*-*-*"
}

widget "gtk-tooltip*" style "tooltips"
' > /tmp/rcgsmix

#and export it...
export RCFILE="/tmp/rcgsmix"

#use rcfile if present
if [ -f $HOME/.aumixrc ]; then
	vol=$(grep -m 1 vol $HOME/.aumixrc | cut -d ":" -f2)
	[ "$vol" = "" ] && vol=0 && vol_vis="Disabled" || vol_vis="Enabeled"
	
	pcm=$(grep -m 1 pcm $HOME/.aumixrc | cut -d ":" -f2)
	[ "$pcm" = "" ] && pcm=0 && pcm_vis="Disabled" || pcm_vis="Enabeled"

	speaker=$(grep -m 1 speaker $HOME/.aumixrc | cut -d ":" -f2)
	[ "$speaker" = "" ] && speaker=0 && speaker_vis="Disabled" || speaker_vis="Enabeled"

	line=$(grep -m 1 line $HOME/.aumixrc | cut -d ":" -f2)
	[ "$line" = "" ] && line=0 && line_vis="Disabled" || line_vis="Enabeled"

	cd=$(grep -m 1 cd $HOME/.aumixrc | cut -d ":" -f2)
	[ "$cd" = "" ] && cd=0 && cd_vis="Disabled" || cd_vis="Enabeled"

else	#use current settings
	aumix -q > current
	vol=$(grep -m 1 vol current | tr -d "," | cut -d " " -f2)
	[ "$vol" = "" ] && vol=0 && vol_vis="Disabled" || vol_vis="Enabeled"

	pcm=$(grep -m 1 pcm current | tr -d "," | cut -d " " -f2)
	[ "$pcm" = "" ] && pcm=0 && pcm_vis="Disabled" || pcm_vis="Enabeled"

	speaker=$(grep -m 1 speaker current | tr -d "," | cut -d " " -f2)
	[ "$speaker" = "" ] && speaker=0 && speaker_vis="Disabled" || speaker_vis="Enabeled"

	line=$(grep -m 1 line current | tr -d "," | cut -d " " -f2)
	[ "$line" = "" ] && line=0 && line_vis="Disabled" || line_vis="Enabeled"

	cd=$(grep -m 1 cd current | tr -d "," | cut -d " " -f2)
	[ "$cd" = "" ] && cd=0 && cd_vis="Disabled" || cd_vis="Enabeled"

fi

#ash function file
echo '

save_settings () {
	aumix -S
}

mute_me () {
	volumes=$(aumix -vq | tr -d "," | cut -d " " -f2)
	if [ $(echo $volumes) -ne 0 ]; then
		aumix -S -v 0
	else
		aumix -L > /dev/null
	fi
}

vol_me () {
	aumix -vq | tr -d "," | cut -d " " -f2
}

' > /tmp/gsmix_ash

export MAIN_DIALOG='
<wtitle>gsmix 0.1</wtitle>
<vbox margin="12">
	<hbox>
		<pixmap>
     		<height>30</height>
     		<width>30</width>
     		<input file>vol.xpm</input>
     	</pixmap>
		<hscale>
			<variable>VOLUME</variable>
			<tooltip>Volume</tooltip>
			<default>'$vol'</default>
			<input>vol_me</input>
			<visible>'$vol_vis'</visible>
			<height>30</height>
			<width>120</width>
			<action>aumix -v $VOLUME</action>	
		</hscale>
	</hbox>
	<hbox>
		<pixmap>
     		<height>30</height>
     		<width>30</width>
     		<input file>pcm.xpm</input>
     	</pixmap>
		<hscale>
			<variable>PCM</variable>
			<tooltip>PCM</tooltip>
			<default>'$pcm'</default>
			<visible>'$pcm_vis'</visible>
			<height>30</height>
			<width>120</width>
			<action>aumix -w $PCM</action>	
		</hscale>
	</hbox>
	
	<hbox>
		<pixmap>
     		<height>30</height>
     		<width>30</width>
     		<input file>speaker.xpm</input>
     	</pixmap>
		<hscale>
			<variable>SPEAKER</variable>
			<tooltip>Speaker</tooltip>
			<default>'$speaker'</default>
			<visible>'$speaker_vis'</visible>
			<height>30</height>
			<width>120</width>
			<action>aumix -p $SPEAKER</action>	
		</hscale>
	</hbox>
	  
	<hbox>
		<pixmap>
     		<height>30</height>
     		<width>30</width>
     		<input file>line.xpm</input>
     	</pixmap>
		<hscale>
			<variable>LINE</variable>
			<tooltip>Line</tooltip>
			<default>'$line'</default>
			<visible>'$line_vis'</visible>
			<height>30</height>
			<width>120</width>
			<action>aumix -l $LINE</action>	
		</hscale>
	</hbox>
	
	<hbox>
		<pixmap>
     		<height>30</height>
     		<width>30</width>
     		<input file>cd.xpm</input>
     	</pixmap>
		<hscale>
			<variable>CD</variable>
			<tooltip>CD</tooltip>
			<default>'$cd'</default>
			<visible>'$cd_vis'</visible>
			<height>30</height>
			<width>120</width>
			<action>aumix -c $CD</action>	
		</hscale>
	</hbox>

	<hseparator></hseparator>
	
	<hbox>
		<button>
			<input file>mute.xpm</input>
			<tooltip>Mute/Un-mute...</tooltip>
			<action>mute_me</action>
			<action>refresh:VOLUME</action>
		</button>
		<button>
			<input file stock="gtk-quit"></input>
			<tooltip>Quit</tooltip>
			<action>save_settings</action>
			<action>exit</action>
		</button>
	</hbox>	
</vbox>
'

gtkdialog1 --center --wmclass gsmix --program=MAIN_DIALOG -i /tmp/gsmix_ash

rm -f current
