#!/bin/ash
#demo script for gtkdialog1 using speak as speach engine
#May_June2013 goingnuts
#TODO:

#show status (stopped/pause/playing)
#change status to stopped when play is done - how???
#message when record done?
#message if filenames for save is empty?

#tested with espeak-1.46.02
[ ! $(which speak) ] && echo "I need program speak to run..." && exit

#set defaults
lang="default"
voice="\"\""
html="false"
pitch=50
speed=175
volume=100
delay=10
#size of buttons
size=20
#relief used
relief="none"

#load previous settings if present
if [ -f $HOME/rcpmspeak ]; then
. $HOME/rcpmspeak
fi

#[[ -x ../../src/gtkdialog1 ]] && PATH=../../src:$PATH

#create list of languages present
for X in $(ls /usr/share/espeak-data/voices/); do
	if [ -f /usr/share/espeak-data/voices/$X ]; then
		LANGS="$LANGS<item>$X</item>"
	fi
done
#create a list of variants present
for X in $(ls /usr/share/espeak-data/voices/!v/); do
	if [ -f /usr/share/espeak-data/voices/!v/$X ]; then
		VARS="$VARS<item>$X</item>"
	fi
done

#create a styleset
echo '
style "tooltips" {
  bg[NORMAL] = "#ffd000"
  fg[NORMAL] = "#000000"
  font = "-adobe-helvetica-medium-r-normal--*-120-*-*-*-*-*-*"
}

widget "gtk-tooltip*" style "tooltips"
' > /tmp/rcpmspeak

#and export it...
export RCFILE="/tmp/rcpmspeak"

#ash function file
echo '

save_settings () {
echo "lang=$LANGUAGE
voice=$VARIANT
html=$HTML
pitch=$PITCH
speed=$SPEED
volume=$VOLUME
delay=$DELAY
" > $HOME/rcpmspeak
}

play_me () { 
#check status - are we playing?
if [ ! "$(pgrep speak)" = "" ]; then 
	kill -CONT $(cat mypid)
	return	
else
	rm -f mypid
	#do not play empty text...
	if [ ! "${MYTEXT}" = "" ]; then
		[ "$HTML" = "true" ] && M="-m" || M=""
		speak ${M} -s $SPEED -a $VOLUME -p $PITCH -g $DELAY -v$LANGUAGE+$VARIANT "${MYTEXT}" &
		echo $! > mypid
	fi
fi
}

pause_me () {
if [ -f mypid ]; then
   	speakPID=$(cat mypid)
	kill -STOP $speakPID
fi
}	

stop_me () {
if [ -f mypid ]; then
    speakPID=$(cat mypid)
   	kill -CONT $speakPID
	kill $speakPID
	killall speak
	rm -f mypid
fi
}	

save_me () {
	#we only check if filename is empty - not if the content is
	if [ ! "${SAVEFILE}" = "" ]; then
		echo "${MYTEXT}" > ${SAVEFILE}
	fi
}

record_me () {
	#dont bother if filename and content is empty
	if [ ! "${RECORDFILE}" = "" ] && [ ! "${MYTEXT}" = "" ]; then
		speak ${M} -s $SPEED -a $VOLUME -p $PITCH -g $DELAY -v$LANGUAGE+$VARIANT "${MYTEXT}" -w "${RECORDFILE%%.*}".wav &
		#check output formate
		if [ "${WAV}" = "false" ]; then
			lame -h "${RECORDFILE%%.*}".wav "${RECORDFILE%%.*}.mp3" &
		fi	
	fi
}


' > /tmp/pmspeak_ash

#the save as GUI
export SAVE_AS='
<wtitle>pmspeak 0.1</wtitle>
<vbox>
	<hbox>
		<entry>
			<tooltip>Write filename to save...</tooltip>
			<variable>SAVEFILE</variable>
		</entry>
		<button>
			<input file stock="gtk-open"></input>
			<label>Select file</label>
			<mini>this is the value of position</mini>
			<tooltip>Browse filesystem...</tooltip>
			<height>'$size'</height>
			<width>'$size'</width>
			<action fileselection>SAVEFILE</action>
		</button>
	</hbox>
	<hbox>
		<button>
			<input file stock="gtk-save"></input>
			<label>Save</label>
			<tooltip>Save the file...</tooltip>
			<action>save_me</action>
			<action>closewindow:SAVE_AS</action>
		</button>
		<button cancel>
			<tooltip>Close without saving...</tooltip>
			<action>closewindow:SAVE_AS</action>
		</button>
	</hbox>	
</vbox>
'

#the record as GUI
export RECORD_AS='
<wtitle>pmspeak 0.1</wtitle>
<vbox>
	<hbox>
		<entry>
			<tooltip>Write filename to save...</tooltip>
			<variable>RECORDFILE</variable>
		</entry>
		<button>
			<input file stock="gtk-open"></input>
			<label>Select file</label>
			<tooltip>Browse filesystem...</tooltip>
			<height>'$size'</height>
			<width>'$size'</width>
			<action fileselection>RECORDFILE</action>
		</button>
	</hbox>
	<hbox>
		<radiobutton>
			<label>wav</label>
			<tooltip>Save as wav-file...</tooltip>
			<default>true</default>
			<variable>WAV</variable>
		</radiobutton>
		<radiobutton>
			<label>mp3</label>
			<tooltip>Save as mp3-file...</tooltip>
		</radiobutton>
	</hbox>
	<hbox>
		<button>
			<input file stock="gtk-save"></input>
			<label>Save</label>
			<tooltip>Save the file...</tooltip>
			<action>record_me</action>
			<action>closewindow:RECORD_AS</action>
		</button>
		<button cancel>
			<tooltip>Close without saving...</tooltip>
			<action>closewindow:RECORD_AS</action>
		</button>
	</hbox>	
</vbox>
'


#the GUI
export MAIN_DIALOG='
<wtitle>pmspeak 0.1</wtitle>
<vbox>
	<hseparator></hseparator>
	# the action buttons
	<hbox>
		<button>
			<input file stock="gtk-new"></input>
			<label>New</label>
			<tooltip>Clear text and stop playing...</tooltip>
			<position>bottom</position>
			<height>'$size'</height>
			<width>'$size'</width>
			<default>'$relief'</default>
			<action clear>MYTEXT</action>
			<action>stop_me</action>
		</button>
		<button>
			<input file stock="gtk-open"></input>
			<label>Open</label>
			<tooltip>Choose a file to play...</tooltip>
			<position>bottom</position>
			<height>'$size'</height>
			<width>'$size'</width>
			<default>'$relief'</default>
			<action fileselection>MYTEXT</action>
		</button>
		<button>
			<input file stock="gtk-save-as"></input>
			<label>Save As</label>
			<tooltip>Save current text to a file...</tooltip>
			<position>bottom</position>
			<height>'$size'</height>
			<width>'$size'</width>
			<default>'$relief'</default>
			<action launchwindow>SAVE_AS</action>
		</button>
		<vseparator></vseparator>
		<button>
			<input file stock="gtk-media-record"></input>
			<label>Record</label>
			<tooltip>Record the current text to an audio file...</tooltip>
			<position>bottom</position>
			<height>'$size'</height>
			<width>'$size'</width>
			<default>'$relief'</default>
			<action launchwindow>RECORD_AS</action>
		</button>
		<vseparator></vseparator>
		<button>
			<input file stock="gtk-quit"></input>
			<label>Quit</label>
			<tooltip>Save current settings and quit program...</tooltip>
			<position>bottom</position>
			<height>'$size'</height>
			<width>'$size'</width>
			<default>'$relief'</default>
			<action>save_settings</action>
			<action>exit</action>
		</button>
	</hbox>
	<hseparator></hseparator>
	#the text area
    <frame Insert text to play>
        <edit>
        	<variable>MYTEXT</variable>
        	<tooltip>Type text or drag and drop a file here...</tooltip>
        </edit>
    
  	<hbox>
  		
    <button>
		<input file stock="gtk-media-play"></input>
		<tooltip>Play</tooltip>
		<action>play_me</action>
	</button>
	<button>
		<input file stock="gtk-media-pause"></input>
		<tooltip>Pause</tooltip>
		<action>pause_me</action>
	</button>
	<button>
		<input file stock="gtk-media-stop"></input>
		<tooltip>Stop</tooltip>
		<action>stop_me</action>
	</button>
	
	</hbox>
	</frame>
	<notebook labels="Base settings|Advanced settings" show-tabs="yes" tabpos="top" >
	#base settings
	<vbox>
    	<hbox>
			<text>
				<label>Language:</label>
			</text>
			<combobox>
				<variable>LANGUAGE</variable>
				<tooltip>Select the language...</tooltip>
				<default>'$lang'</default>
				'$LANGS'
            </combobox>
		</hbox>
		<hbox>
			<text>
				<label>Voice:</label>
			</text>
			<combobox>
				<variable>VARIANT</variable>
				<tooltip>Select the voice or special effect to use...</tooltip>
				<default>'$voice'</default>
				'$VARS'
            </combobox>
        </hbox>
		<hbox>
            #if the -m option is used then HTML can be spoken directly.
            <checkbox>
				<label>HTML text</label>
				<tooltip>Check this if text contains HTML syntax...</tooltip>
				<default>'$html'</default>
				<variable>HTML</variable>
		</checkbox>
		</hbox>
	</vbox>
	<vbox>
    # Pitch adjustment, 0 to 99, default is 50
    	<hbox>
			<text>
				<label>Pitch:</label>
			</text>
			<hscale>
				<variable>PITCH</variable>
				<tooltip>Pitch adjustment...</tooltip>
				<default>'$pitch'</default>
				<mini>0</mini>
				<maxi>99</maxi>
				<height>30</height>
				<width>150</width>	
			</hscale>
		</hbox>
		# Amplitude, 0 to 200, default is 100
		<hbox>
			<text>
				<label>Volume:</label>
			</text>
			<hscale>
				<variable>VOLUME</variable>
				<tooltip>Sets the volume...</tooltip>
				<default>'$volume'</default>
				<mini>0</mini>
				<maxi>200</maxi>
				<height>30</height>
				<width>150</width>	
			</hscale>
		</hbox>
		# Speed in words per minute, 80 to 450, default is 175
		<hbox>
			<text>
				<label>Speed:</label>
			</text>
			<hscale>
				<variable>SPEED</variable>
				<tooltip>Speed in words per minute...</tooltip>
				<default>'$speed'</default>
				<mini>80</mini>
				<maxi>270</maxi>
				<height>30</height>
				<width>150</width>	
			</hscale>
		</hbox>
		
        # Word gap. Pause between words, units of 10mS at the default speed
		<hbox>
			<text>
				<label>Delay:</label>
			</text>
			<hscale>
				<variable>DELAY</variable>
				<tooltip>Pause between words (units of 10mS)...</tooltip>
				<default>'$delay'</default>
				<mini>0</mini>
				<maxi>100</maxi>
				<height>30</height>
				<width>150</width>	
			</hscale>
		</hbox>
    </vbox>
    </notebook>
</vbox>
'

gtkdialog1 --center --wmclass pmspeak --program=MAIN_DIALOG -i /tmp/pmspeak_ash

rm -f /tmp/pmspeak_ash status mypid rcpmspeak
killall speak

wait

exit
